==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GroupDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GroupDataDescription } from "./GroupDataDescription";
/**
 * @hidden
 */
export let GroupDataDescriptionMetadata = /*@__PURE__*/ (() => {
    class GroupDataDescriptionMetadata extends Base {
        static b(a) {
            if (GroupDataDescriptionMetadata.a == null) {
                GroupDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GroupDataDescriptionMetadata.c(GroupDataDescriptionMetadata.a);
            }
            if (a.k(GroupDataDescriptionMetadata.a)) {
                return;
            }
            a.ab(GroupDataDescriptionMetadata.a);
        }
        static c(a) {
            a.item("GroupName", "String");
            a.item("GroupValueRef", "(w:GroupValue,wf:GroupValue)DataRef");
            a.item("FormattedText", "String");
        }
        static d(a) {
            GroupDataDescriptionMetadata.b(a);
            a.ad("GroupData", () => new GroupDataDescription());
            a.ac("GroupData", GroupDataDescriptionMetadata.a);
        }
    }
    GroupDataDescriptionMetadata.$t = markType(GroupDataDescriptionMetadata, 'GroupDataDescriptionMetadata');
    GroupDataDescriptionMetadata.a = null;
    return GroupDataDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GroupDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GroupDataDescription } from "./GroupDataDescription";
/**
 * @hidden
 */
export let GroupDataDescriptionMetadata = /*@__PURE__*/ (() => {
    class GroupDataDescriptionMetadata extends Base {
        static b(a) {
            if (GroupDataDescriptionMetadata.a == null) {
                GroupDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GroupDataDescriptionMetadata.c(GroupDataDescriptionMetadata.a);
            }
            if (a.k(GroupDataDescriptionMetadata.a)) {
                return;
            }
            a.ac(GroupDataDescriptionMetadata.a);
        }
        static c(a) {
            a.item("GroupName", "String");
            a.item("GroupValueRef", "(w:GroupValue,wf:GroupValue)DataRef");
            a.item("FormattedText", "String");
        }
        static d(a) {
            GroupDataDescriptionMetadata.b(a);
            a.ae("GroupData", () => new GroupDataDescription());
            a.ad("GroupData", GroupDataDescriptionMetadata.a);
        }
    }
    GroupDataDescriptionMetadata.$t = markType(GroupDataDescriptionMetadata, 'GroupDataDescriptionMetadata');
    GroupDataDescriptionMetadata.a = null;
    return GroupDataDescriptionMetadata;
})();
